import {
  Sequelize,
  DataTypes,
  Model,
  Optional,
  Association,
  HasManyAddAssociationMixin,
  BelongsToManySetAssociationsMixin,
} from "sequelize";
import Sport from "./Sport";

interface BoatTypeAttributes {
  id: string;
  name: string;
  seats: number;
}
export interface BoatTypeInput extends Optional<BoatTypeAttributes, "id"> {}

class BoatType
  extends Model<BoatTypeAttributes, BoatTypeInput>
  implements BoatTypeAttributes
{
  declare id: string;
  declare name: string;
  declare seats: number;

  declare readonly createdAt: Date;
  declare readonly updatedAt: Date;

  public addSport: HasManyAddAssociationMixin<Sport, any>;
  public setSports!: BelongsToManySetAssociationsMixin<Sport, number>
  declare readonly sports?: Sport[];

  declare static associations: {
    sports: Association<BoatType, Sport>;
  };
}

export const initBoatType = async (sequelizeConnection: Sequelize) => {
  BoatType.init(
    {
      id: {
        type: DataTypes.UUID,
        defaultValue: DataTypes.UUIDV4,
        primaryKey: true,
        allowNull: false,
      },
      name: {
        type: new DataTypes.STRING(),
        allowNull: false,
      },
      seats: {
        type: DataTypes.INTEGER,
        allowNull: false,
      },
    },
    {
      tableName: "boattype",
      sequelize: sequelizeConnection,
    }
  );
  return BoatType
};
export default BoatType;
