import { Router } from "express";
import { body } from "express-validator";
import handleValidationResult from "../middleware/handleValidationResult";
import {checkInController, checkOutController, getCheckInController} from "../controllers/createLogEntry.controllers";

const entryRouter = Router();

entryRouter.post(
  "/api/checkin/",
  body("startTime").isISO8601(),
  body("estimatedEndTime").isISO8601(),
  body("destination").isString(),
  body("email").isEmail().normalizeEmail(),
  body("responsible").not().isEmpty(),
  body("persons").if(body("persons").exists()).isArray(),
  handleValidationResult,
  checkInController
);

entryRouter.post(
  "/api/checkout/:id",
  checkOutController
);

entryRouter.get(
  "/api/checkin/:id",
  getCheckInController
)


export default entryRouter;